Experimental Inference tools
============================

The following tools are experimental and may change in future releases. They help
with the Bayesian inference of the model parameters using the `PyMC <https://www.pymc
.io/>`_ library.


Functions
---------

.. automodule:: icomo.experimental
    :imported-members:
    :members:
    :show-inheritance:
